@@ -1,8 +1,7 @@
 "addOutlierWeights" <- function(m, weightListOutliers) {
-  for(i in 1:length(m))
+  for (i in 1:length(m)) {
     m[[i]]@weightM <- weightListOutliers[[i]]
- 
+  }
+
   m
-
-
 }
